==> config-api-0.3.26-sources.jar: org/wildfly/swarm/config/singleton/singleton_policy/SimpleElectionPolicy.java <==
package org.wildfly.swarm.config.singleton.singleton_policy;

import org.wildfly.swarm.config.runtime.Address;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.Implicit;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyChangeListener;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.List;
import java.util.Arrays;
/**
 * A simple election policy
 */
@Address("/subsystem=singleton/singleton-policy=*/election-policy=simple")
@ResourceType("election-policy")
@Implicit
public class SimpleElectionPolicy<T extends SimpleElectionPolicy<T>> {

	private String key;
	private PropertyChangeSupport pcs;
	private List<String> namePreferences;
	private Integer position;
	private List<String> socketBindingPreferences;

	public SimpleElectionPolicy() {
		this.key = "simple";
		this.pcs = new PropertyChangeSupport(this);
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Adds a property change listener
	 */
	public void addPropertyChangeListener(PropertyChangeListener listener) {
		if (null == this.pcs)
			this.pcs = new PropertyChangeSupport(this);
		this.pcs.addPropertyChangeListener(listener);
	}

	/**
	 * Removes a property change listener
	 */
	public void removePropertyChangeListener(PropertyChangeListener listener) {
		if (this.pcs != null)
			this.pcs.removePropertyChangeListener(listener);
	}

	/**
	 * The list of preferred node names
	 */
	@ModelNodeBinding(detypedName = "name-preferences")
	public List<String> namePreferences() {
		return this.namePreferences;
	}

	/**
	 * The list of preferred node names
	 */
	@SuppressWarnings("unchecked")
	public T namePreferences(List<String> value) {
		Object oldValue = this.namePreferences;
		this.namePreferences = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("namePreferences", oldValue, value);
		return (T) this;
	}

	/**
	 * The list of preferred node names
	 */
	@SuppressWarnings("unchecked")
	public T namePreference(String value) {
		if (this.namePreferences == null) {
			this.namePreferences = new java.util.ArrayList<>();
		}
		this.namePreferences.add(value);
		return (T) this;
	}

	/**
	 * The list of preferred node names
	 */
	@SuppressWarnings("unchecked")
	public T namePreferences(String... args) {
		namePreferences(Arrays.asList(args));
		return (T) this;
	}

	/**
	 * The position in the membership list from which the singleton master will
	 * be chosen
	 */
	@ModelNodeBinding(detypedName = "position")
	public Integer position() {
		return this.position;
	}

	/**
	 * The position in the membership list from which the singleton master will
	 * be chosen
	 */
	@SuppressWarnings("unchecked")
	public T position(Integer value) {
		Object oldValue = this.position;
		this.position = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("position", oldValue, value);
		return (T) this;
	}

	/**
	 * The list of preferred node socket bindings
	 */
	@ModelNodeBinding(detypedName = "socket-binding-preferences")
	public List<String> socketBindingPreferences() {
		return this.socketBindingPreferences;
	}

	/**
	 * The list of preferred node socket bindings
	 */
	@SuppressWarnings("unchecked")
	public T socketBindingPreferences(List<String> value) {
		Object oldValue = this.socketBindingPreferences;
		this.socketBindingPreferences = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("socketBindingPreferences", oldValue,
					value);
		return (T) this;
	}

	/**
	 * The list of preferred node socket bindings
	 */
	@SuppressWarnings("unchecked")
	public T socketBindingPreference(String value) {
		if (this.socketBindingPreferences == null) {
			this.socketBindingPreferences = new java.util.ArrayList<>();
		}
		this.socketBindingPreferences.add(value);
		return (T) this;
	}

	/**
	 * The list of preferred node socket bindings
	 */
	@SuppressWarnings("unchecked")
	public T socketBindingPreferences(String... args) {
		socketBindingPreferences(Arrays.asList(args));
		return (T) this;
	}
}

==> config-api-0.4.4-sources.jar: org/wildfly/swarm/config/singleton/singleton_policy/SimpleElectionPolicy.java <==
package org.wildfly.swarm.config.singleton.singleton_policy;

import org.wildfly.swarm.config.runtime.Address;
import java.util.HashMap;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.Implicit;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyChangeListener;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.List;
import java.util.Arrays;
/**
 * A simple election policy
 */
@Address("/subsystem=singleton/singleton-policy=*/election-policy=simple")
@ResourceType("election-policy")
@Implicit
public class SimpleElectionPolicy<T extends SimpleElectionPolicy<T>>
		extends
			HashMap {

	private String key;
	private PropertyChangeSupport pcs;
	private List<String> namePreferences;
	private Integer position;
	private List<String> socketBindingPreferences;

	public SimpleElectionPolicy() {
		super();
		this.key = "simple";
		this.pcs = new PropertyChangeSupport(this);
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Adds a property change listener
	 */
	public void addPropertyChangeListener(PropertyChangeListener listener) {
		if (null == this.pcs)
			this.pcs = new PropertyChangeSupport(this);
		this.pcs.addPropertyChangeListener(listener);
	}

	/**
	 * Removes a property change listener
	 */
	public void removePropertyChangeListener(PropertyChangeListener listener) {
		if (this.pcs != null)
			this.pcs.removePropertyChangeListener(listener);
	}

	/**
	 * The list of preferred node names
	 */
	@ModelNodeBinding(detypedName = "name-preferences")
	public List<String> namePreferences() {
		return this.namePreferences;
	}

	/**
	 * The list of preferred node names
	 */
	@SuppressWarnings("unchecked")
	public T namePreferences(List<String> value) {
		Object oldValue = this.namePreferences;
		this.namePreferences = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("namePreferences", oldValue, value);
		return (T) this;
	}

	/**
	 * The list of preferred node names
	 */
	@SuppressWarnings("unchecked")
	public T namePreference(String value) {
		if (this.namePreferences == null) {
			this.namePreferences = new java.util.ArrayList<>();
		}
		this.namePreferences.add(value);
		return (T) this;
	}

	/**
	 * The list of preferred node names
	 */
	@SuppressWarnings("unchecked")
	public T namePreferences(String... args) {
		namePreferences(Arrays.asList(args));
		return (T) this;
	}

	/**
	 * The position in the membership list from which the singleton master will
	 * be chosen
	 */
	@ModelNodeBinding(detypedName = "position")
	public Integer position() {
		return this.position;
	}

	/**
	 * The position in the membership list from which the singleton master will
	 * be chosen
	 */
	@SuppressWarnings("unchecked")
	public T position(Integer value) {
		Object oldValue = this.position;
		this.position = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("position", oldValue, value);
		return (T) this;
	}

	/**
	 * The list of preferred node socket bindings
	 */
	@ModelNodeBinding(detypedName = "socket-binding-preferences")
	public List<String> socketBindingPreferences() {
		return this.socketBindingPreferences;
	}

	/**
	 * The list of preferred node socket bindings
	 */
	@SuppressWarnings("unchecked")
	public T socketBindingPreferences(List<String> value) {
		Object oldValue = this.socketBindingPreferences;
		this.socketBindingPreferences = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("socketBindingPreferences", oldValue,
					value);
		return (T) this;
	}

	/**
	 * The list of preferred node socket bindings
	 */
	@SuppressWarnings("unchecked")
	public T socketBindingPreference(String value) {
		if (this.socketBindingPreferences == null) {
			this.socketBindingPreferences = new java.util.ArrayList<>();
		}
		this.socketBindingPreferences.add(value);
		return (T) this;
	}

	/**
	 * The list of preferred node socket bindings
	 */
	@SuppressWarnings("unchecked")
	public T socketBindingPreferences(String... args) {
		socketBindingPreferences(Arrays.asList(args));
		return (T) this;
	}
}
